@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef GRANTLEETHEMETEST_H
-#define GRANTLEETHEMETEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class GrantleeThemeTest : public QObject
     Q_OBJECT
 public:
     explicit GrantleeThemeTest(QObject *parent = nullptr);
-    ~GrantleeThemeTest();
+    ~GrantleeThemeTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldInvalidWhenPathIsNotValid();
@@ -26,7 +25,6 @@ private Q_SLOTS:
 
 private:
     bool validateHtml(const QString &path, const QString &name, const QString &html);
-    bool compareHtml(const QString &path, const QString &name);
+    bool compareHtml(const QString &generatedTheme, const QString &path, const QString &name);
 };
 
-#endif // GRANTLEETHEMETEST_H
